@@ -4,17 +4,22 @@
 from django.db import DatabaseError
 import pyodbc as Database
 
+from collections import namedtuple
+
 from django import VERSION
-from django.db.backends.base.introspection import (
-    BaseDatabaseIntrospection, FieldInfo, TableInfo,
-)
+from django.db.backends.base.introspection import BaseDatabaseIntrospection
+from django.db.backends.base.introspection import FieldInfo as BaseFieldInfo
+from django.db.backends.base.introspection import TableInfo as BaseTableInfo
 from django.db.models.indexes import Index
 from django.conf import settings
 
 SQL_AUTOFIELD = -777555
 SQL_BIGAUTOFIELD = -777444
+SQL_SMALLAUTOFIELD = -777333
 SQL_TIMESTAMP_WITH_TIMEZONE = -155
 
+FieldInfo = namedtuple("FieldInfo", BaseFieldInfo._fields + ("comment",))
+TableInfo = namedtuple("TableInfo", BaseTableInfo._fields + ("comment",))
 
 def get_schema_name():
     return getattr(settings, 'SCHEMA_TO_INSPECT', 'SCHEMA_NAME()')
@@ -25,6 +30,7 @@ class DatabaseIntrospection(BaseDatabaseIntrospection):
     data_types_reverse = {
         SQL_AUTOFIELD: 'AutoField',
         SQL_BIGAUTOFIELD: 'BigAutoField',
+        SQL_SMALLAUTOFIELD: 'SmallAutoField',
         Database.SQL_BIGINT: 'BigIntegerField',
         # Database.SQL_BINARY:            ,
         Database.SQL_BIT: 'BooleanField',
@@ -71,13 +77,26 @@ class DatabaseIntrospection(BaseDatabaseIntrospection):
         """
         Returns a list of table and view names in the current database.
         """
-        sql = 'SELECT TABLE_NAME, TABLE_TYPE FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_SCHEMA = %s' % (
+        sql = """SELECT
+                    TABLE_NAME,
+                    TABLE_TYPE,
+                    CAST(ep.value AS VARCHAR) AS COMMENT
+                FROM INFORMATION_SCHEMA.TABLES i
+                LEFT JOIN sys.tables t ON t.name = i.TABLE_NAME
+                LEFT JOIN sys.extended_properties ep ON t.object_id = ep.major_id
+                AND ((ep.name = 'MS_DESCRIPTION' AND ep.minor_id = 0) OR ep.value IS NULL)
+                AND i.TABLE_SCHEMA = %s""" % (
             get_schema_name())
         cursor.execute(sql)
         types = {'BASE TABLE': 't', 'VIEW': 'v'}
-        return [TableInfo(row[0], types.get(row[1]))
-                for row in cursor.fetchall()
-                if row[0] not in self.ignored_tables]
+        if VERSION >= (4, 2):
+            return [TableInfo(row[0], types.get(row[1]), row[2])
+                    for row in cursor.fetchall()
+                    if row[0] not in self.ignored_tables]
+        else:
+            return [BaseTableInfo(row[0], types.get(row[1]))
+                    for row in cursor.fetchall()
+                    if row[0] not in self.ignored_tables]
 
     def _is_auto_field(self, cursor, table_name, column_name):
         """
@@ -107,11 +126,11 @@ class DatabaseIntrospection(BaseDatabaseIntrospection):
         """
 
         # map pyodbc's cursor.columns to db-api cursor description
-        columns = [[c[3], c[4], None, c[6], c[6], c[8], c[10], c[12]] for c in cursor.columns(table=table_name)]
+        columns = [[c[3], c[4], c[6], c[6], c[6], c[8], c[10], c[12]] for c in cursor.columns(table=table_name)]
 
         if not columns:
             raise DatabaseError(f"Table {table_name} does not exist.")
-            
+
         items = []
         for column in columns:
             if VERSION >= (3, 2):
@@ -126,15 +145,40 @@ class DatabaseIntrospection(BaseDatabaseIntrospection):
                     column.append(collation_name[0] if collation_name else '')
                 else:
                     column.append('')
-
+            if VERSION >= (4, 2):
+                sql = """select CAST(ep.value AS VARCHAR) AS COMMENT
+                        FROM sys.columns c
+                        INNER JOIN sys.tables t ON c.object_id = t.object_id
+                        INNER JOIN sys.extended_properties ep ON c.object_id=ep.major_id AND ep.minor_id = c.column_id
+                        WHERE t.name = '%s' AND c.name = '%s' AND ep.name = 'MS_Description'
+                        """ % (table_name, column[0])
+                cursor.execute(sql)
+                comment = cursor.fetchone()
+                column.append(comment[0] if comment else '')
             if identity_check and self._is_auto_field(cursor, table_name, column[0]):
                 if column[1] == Database.SQL_BIGINT:
                     column[1] = SQL_BIGAUTOFIELD
+                elif column[1] == Database.SQL_SMALLINT:
+                    column[1] = SQL_SMALLAUTOFIELD
                 else:
                     column[1] = SQL_AUTOFIELD
             if column[1] == Database.SQL_WVARCHAR and column[3] < 4000:
                 column[1] = Database.SQL_WCHAR
-            items.append(FieldInfo(*column))
+            # Remove surrounding parentheses for default values
+            if column[7]:
+                default_value = column[7]
+                start = 0
+                end = -1
+                for _ in range(2):
+                    if default_value[start] == '(' and default_value[end] == ')':
+                        start += 1
+                        end -= 1
+                column[7] = default_value[start:end + 1]
+
+            if VERSION >= (4, 2):
+                items.append(FieldInfo(*column))
+            else:
+                items.append(BaseFieldInfo(*column))
         return items
 
     def get_sequences(self, cursor, table_name, table_fields=()):
@@ -271,6 +315,7 @@ WHERE a.TABLE_SCHEMA = {get_schema_name()} AND a.TABLE_NAME = %s AND a.CONSTRAIN
                     # Potentially misleading: primary key and unique constraints still have indexes attached to them.
                     # Should probably be updated with the additional info from the sys.indexes table we fetch later on.
                     "index": False,
+                    "default": False,
                 }
             # Record the details
             constraints[constraint]['columns'].append(column)
@@ -298,6 +343,32 @@ WHERE a.TABLE_SCHEMA = {get_schema_name()} AND a.TABLE_NAME = %s AND a.CONSTRAIN
                     "foreign_key": None,
                     "check": True,
                     "index": False,
+                    "default": False,
+                }
+            # Record the details
+            constraints[constraint]['columns'].append(column)
+        # Now get DEFAULT constraint columns
+        cursor.execute("""
+            SELECT
+                [name],
+                COL_NAME([parent_object_id], [parent_column_id])
+            FROM
+                [sys].[default_constraints]
+            WHERE
+                OBJECT_NAME([parent_object_id]) = %s
+        """, [table_name])
+        for constraint, column in cursor.fetchall():
+            # If we're the first column, make the record
+            if constraint not in constraints:
+                constraints[constraint] = {
+                    "columns": [],
+                    "primary_key": False,
+                    "unique": False,
+                    "unique_constraint": False,
+                    "foreign_key": None,
+                    "check": False,
+                    "index": False,
+                    "default": True,
                 }
             # Record the details
             constraints[constraint]['columns'].append(column)
@@ -341,6 +412,7 @@ WHERE a.TABLE_SCHEMA = {get_schema_name()} AND a.TABLE_NAME = %s AND a.CONSTRAIN
                     "unique_constraint": unique_constraint,
                     "foreign_key": None,
                     "check": False,
+                    "default": False,
                     "index": True,
                     "orders": [],
                     "type": Index.suffix if type_ in (1, 2) else desc.lower(),
