@@ -3,11 +3,14 @@ import logging
 import django.db
 from django import VERSION
 from django.apps import apps
-from django.db import models
+from django.db import models, migrations
+from django.db.migrations.migration import Migration
+from django.db.migrations.state import ProjectState
 from django.db.models import UniqueConstraint
 from django.db.utils import DEFAULT_DB_ALIAS, ConnectionHandler, ProgrammingError
 from django.test import TestCase
 
+from . import get_constraints
 from ..models import (
     TestIndexesRetainedRenamed,
     Choice,
@@ -26,14 +29,6 @@ else:
 logger = logging.getLogger('mssql.tests')
 
 
-def _get_constraints(table_name):
-    connection = django.db.connections[django.db.DEFAULT_DB_ALIAS]
-    return connection.introspection.get_constraints(
-        connection.cursor(),
-        table_name=table_name,
-    )
-
-
 class TestIndexesRetained(TestCase):
     """
     Issue https://github.com/microsoft/mssql-django/issues/14
@@ -46,7 +41,7 @@ class TestIndexesRetained(TestCase):
         super().setUpClass()
         # Pre-fetch which indexes exist for the relevant test model
         # now that all the test migrations have run
-        cls.constraints = _get_constraints(table_name=TestIndexesRetainedRenamed._meta.db_table)
+        cls.constraints = get_constraints(table_name=TestIndexesRetainedRenamed._meta.db_table)
         cls.indexes = {k: v for k, v in cls.constraints.items() if v['index'] is True}
 
     def _assert_index_exists(self, columns):
@@ -97,7 +92,7 @@ class TestCorrectIndexes(TestCase):
             if not model_cls._meta.managed:
                 # Models where the table is not managed by Django migrations are irrelevant
                 continue
-            model_constraints = _get_constraints(table_name=model_cls._meta.db_table)
+            model_constraints = get_constraints(table_name=model_cls._meta.db_table)
             # Check correct indexes are in place for all fields in model
             for field in model_cls._meta.get_fields():
                 if not hasattr(field, 'column'):
@@ -182,3 +177,36 @@ class TestIndexesBeingDropped(TestCase):
                 editor.alter_field(Choice, old_field, new_field, strict=True)
         except ProgrammingError:
             self.fail("Unique indexes not being dropped")
+
+class TestAddAndAlterUniqueIndex(TestCase):
+
+    def test_alter_unique_nullable_to_non_nullable(self):
+        """
+        Test a single migration that creates a field with unique=True and null=True and then alters
+        the field to set null=False. See https://github.com/microsoft/mssql-django/issues/22
+        """
+        operations = [
+            migrations.CreateModel(
+                "TestAlterNullableInUniqueField",
+                [
+                    ("id", models.AutoField(primary_key=True)),
+                    ("a", models.CharField(max_length=4, unique=True, null=True)),
+                ]
+            ),
+            migrations.AlterField(
+                "testalternullableinuniquefield",
+                "a",
+                models.CharField(max_length=4, unique=True)
+            )
+        ]
+
+        project_state = ProjectState()
+        new_state = project_state.clone()
+        migration = Migration("name", "testapp")
+        migration.operations = operations
+
+        try:
+            with connection.schema_editor(atomic=True) as editor:
+                migration.apply(new_state, editor)
+        except django.db.utils.ProgrammingError as e:
+            self.fail('Check if can alter field from unique, nullable to unique non-nullable for issue #23, AlterField failed with exception: %s' % e)
